@@ -80,18 +80,6 @@ assuan_set_flag (assuan_context_t ctx, assuan_flag_t flag, int value)
     case ASSUAN_NO_FIXSIGNALS:
       ctx->flags.no_fixsignals = value;
       break;
-
-    case ASSUAN_CONVEY_COMMENTS:
-      ctx->flags.convey_comments = value;
-      break;
-
-    case ASSUAN_NO_LOGGING:
-      ctx->flags.no_logging = value;
-      break;
-
-    case ASSUAN_FORCE_CLOSE:
-      ctx->flags.force_close = 1;
-      break;
     }
 }
 
@@ -120,25 +108,13 @@ assuan_get_flag (assuan_context_t ctx, assuan_flag_t flag)
     case ASSUAN_NO_FIXSIGNALS:
       res = ctx->flags.no_fixsignals;
       break;
-
-    case ASSUAN_CONVEY_COMMENTS:
-      res = ctx->flags.convey_comments;
-      break;
-
-    case ASSUAN_NO_LOGGING:
-      res = ctx->flags.no_logging;
-      break;
-
-    case ASSUAN_FORCE_CLOSE:
-      res = ctx->flags.force_close;
-      break;
     }
 
   return TRACE_SUC1 ("flag_value=%i", res);
 }
 
 
-/* Same as assuan_set_flag (ctx, ASSUAN_CONFIDENTIAL, 1).  */
+/* Same as assuan_set_flag (ctx, ASSUAN_NO_WAITPID, 1).  */
 void
 assuan_begin_confidential (assuan_context_t ctx)
 {
@@ -146,7 +122,7 @@ assuan_begin_confidential (assuan_context_t ctx)
 }
 
 
-/* Same as assuan_set_flag (ctx, ASSUAN_CONFIDENTIAL, 0).  */
+/* Same as assuan_set_flag (ctx, ASSUAN_NO_WAITPID, 0).  */
 void
 assuan_end_confidential (assuan_context_t ctx)
 {
@@ -190,8 +166,8 @@ assuan_set_error (assuan_context_t ctx, gpg_error_t err, const char *text)
 {
   TRACE4 (ctx, ASSUAN_LOG_CTX, "assuan_set_error", ctx,
 	  "err=%i (%s,%s),text=%s", err, gpg_strsource (err),
-	  gpg_strerror (err), text?text:"(none)");
-
+	  gpg_strerror (err), text);
+  
   ctx->err_no = err;
   ctx->err_str = text;
   return err;
