@@ -25,9 +25,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <time.h>
-# ifdef HAVE_WINSOCK2_H
-#  include <winsock2.h>
-# endif 
+#include <fcntl.h>
 #include <windows.h>
 #include <winioctl.h>
 #include <devload.h>
@@ -660,31 +658,6 @@ __assuan_socketpair (assuan_context_t ctx, int namespace, int style,
 }
 
 
-int
-__assuan_socket (assuan_context_t ctx, int namespace, int style, int protocol)
-{
-  int res;
-
-  res = socket (domain, type, proto);
-  if (res == -1)
-    gpg_err_set_errno (_assuan_sock_wsa2errno (WSAGetLastError ()));
-  return res;
-}
-
-
-int
-__assuan_connect (assuan_context_t ctx, int sock, struct sockaddr *addr,
-		  socklen_t length)
-{
-  int res;
-
-  res = connect (sock, addr, length);
-  if (res < 0)
-    gpg_err_set_errno (_assuan_sock_wsa2errno (WSAGetLastError ()));
-  return res;
-}
-
-
 
 /* The default system hooks for assuan contexts.  */
 struct assuan_system_hooks _assuan_system_hooks =
@@ -699,7 +672,5 @@ struct assuan_system_hooks _assuan_system_hooks =
     __assuan_sendmsg,
     __assuan_spawn,
     __assuan_waitpid,
-    __assuan_socketpair,
-    __assuan_socket,
-    __assuan_connect    
+    __assuan_socketpair    
   };
